%define name    OpenIPMI2
%define version 2.0.6
%define release %mkrel 10

Name: 		%{name}
Summary: 	%{name} - Library interface to IPMI
Version: 	%{version}
Release: 	%{release}
License: 	LGPL
URL: 		http://openipmi.sourceforge.net
Group: 		System/Kernel and hardware
Source: 	OpenIPMI-%{version}.tar.bz2
Buildroot: 	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:	pkgconfig swig >= 1.3 python-devel
BuildRequires:	popt-devel ncurses-devel net-snmp-devel
BuildRequires:	libgdbm-devel perl-devel glib2-devel
Conflicts:	OpenIPMI
Requires(pre):	rpm-helper
Requires(post): rpm-helper

# Perl is usually installed in /usr/lib, not /usr/lib64 on 64-bit platforms.
#%define perl_libdir %{_exec_prefix}/lib

%description 
This package contains a shared library implementation of IPMI and the
basic tools used with OpenIPMI.

%package	devel
Summary:	Development files for OpenIPMI
Group:		Development/C
Requires:	%{name} = %{version} pkgconfig

%description	devel
Contains additional files need for a developer to create applications
and/or middleware that depends on libOpenIPMI

%package	perl
Summary:	Perl interface for OpenIPMI
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}

%description	perl
A Perl interface for OpenIPMI.

%package	python
Summary:	Python interface for OpenIPMI
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}

%description	python
A Python interface for OpenIPMI.

#The gui package is disabled for now as I don't find
#why the LD_LIBRARY_PATH=../../../lib/.libs:../../../utils/.libs:../../../glib/.libs:../../../cmdlang/.libs:../../..//unix/.libs/ PYTHONPATH=../../../swig/python:. /usr/bin/python -c 'import _control' doesn't use the LD_LIBRARY_PATH to find libOpenIPMIpthread.so.0
#%package	gui
#Summary:	GUI (in python) for OpenIPMI
#Group:		Utilities
#Requires:	%{name}-python = %{version} wxPython >= 2.4.2 wxPythonGTK

#%description	gui
#A GUI interface for OpenIPMI.  Written in python an requiring wxWidgets.

%package	ui
Summary:	User Interface (ui)
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}

%description	ui
This package contains a user interface

%package	lanserv
Summary:	Emulates an IPMI network listener
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}

%description	lanserv
This package contains a network IPMI listener.

###################################################
%prep
###################################################
%setup -q -n OpenIPMI-%{version}

###################################################
%build
###################################################
# Disabling the gui
%configure2_5x	--with-wxpython=no \
		--with-perlinstall=%{perl_vendorarch} \
		--with-pythoninstall=%{py_platsitedir} \
		--with-glib12=no
%make

###################################################
%install
###################################################
rm -rf %{buildroot}
%makeinstall_std
install -m755 ipmi.init -D %{buildroot}/%{_sysconfdir}/init.d/ipmi
install -m644 ipmi.sysconf -D %{buildroot}/%{_sysconfdir}/sysconfig/ipmi

###################################################
%preun
###################################################
%_preun_service ipmi

###################################################
%postun
###################################################
/sbin/ldconfig
%_post_service ipmi

%post -p /sbin/ldconfig

%post ui -p /sbin/ldconfig

%postun ui -p /sbin/ldconfig

%post lanserv -p /sbin/ldconfig

%postun lanserv
/sbin/ldconfig

%clean
rm -rf %{buildroot}

###################################################
%files
###################################################
%defattr(-,root,root)
%{_libdir}/libOpenIPMIcmdlang.so.*
%{_libdir}/libOpenIPMIcmdlang.la
%{_libdir}/libOpenIPMIglib.so.*
%{_libdir}/libOpenIPMIglib.la
%{_libdir}/libOpenIPMIposix.so*
%{_libdir}/libOpenIPMIposix.la
%{_libdir}/libOpenIPMIpthread.so.*
%{_libdir}/libOpenIPMIpthread.la
%{_libdir}/libOpenIPMI.so.*
%{_libdir}/libOpenIPMI.la
%{_libdir}/libOpenIPMIutils.so.*
%{_libdir}/libOpenIPMIutils.la
%{_sysconfdir}/init.d/ipmi
%config(noreplace) %{_sysconfdir}/sysconfig/ipmi
%doc COPYING COPYING.LIB FAQ INSTALL README README.Force
%doc README.MotorolaMXP


###################################################
%files perl
###################################################
%defattr(-,root,root)
%{perl_vendorarch}/OpenIPMI.pm
%{perl_vendorarch}/auto/OpenIPMI/*
%doc swig/OpenIPMI.i swig/perl/sample swig/perl/ipmi_powerctl

###################################################
%files python
###################################################
%defattr(-,root,root)
%{_libdir}/python*/site-packages/*OpenIPMI.*
%doc swig/OpenIPMI.i

###################################################
#%files gui
###################################################
#%defattr(-,root,root)
#%dir %{_libdir}/python*/site-packages/openipmigui
#%{_libdir}/python*/site-packages/openipmigui/*
#%{_bindir}/openipmigui

###################################################
%files devel
###################################################
%defattr(-,root,root)
%{_includedir}/OpenIPMI
%{_libdir}/*.a
%{_libdir}/*.so
%exclude %{_libdir}/libIPMIlanserv.so
%exclude %{_libdir}/libOpenIPMIui.so
%{_libdir}/pkgconfig
%doc doc/IPMI.pdf

###################################################
%files ui
###################################################
%defattr(-,root,root)
%{_bindir}/ipmi_ui
%{_bindir}/ipmicmd
%{_bindir}/openipmicmd
%{_bindir}/ipmish
%{_bindir}/openipmish
%{_bindir}/solterm
%{_bindir}/rmcp_ping
%{_libdir}/libOpenIPMIui.so*
%{_libdir}/libOpenIPMIui.la
%doc %{_mandir}/man1/ipmi_ui.1*
%doc %{_mandir}/man1/openipmicmd.1*
%doc %{_mandir}/man1/openipmish.1*
%doc %{_mandir}/man1/openipmigui.1*
%doc %{_mandir}/man1/solterm.1*
%doc %{_mandir}/man1/rmcp_ping.1*
%doc %{_mandir}/man7/ipmi_cmdlang.7*
%doc %{_mandir}/man7/openipmi_conparms.7*

###################################################
%files lanserv
###################################################
%defattr(-,root,root)
%{_bindir}/ipmilan
%{_libdir}/libIPMIlanserv.so*
%{_libdir}/libIPMIlanserv.la
%doc %{_mandir}/man8/ipmilan.8*


%changelog
* Fri Jan 19 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-10mdv2007.0
+ Revision: 110611
- fix group og -devel package (fixes #28150)

* Fri Dec 15 2006 Nicolas Lécureuil <neoclust@mandriva.org> 2.0.6-9mdv2007.1
+ Revision: 97904
- Rebuild against new Python
- Import OpenIPMI2



* Mon Sep 18 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.0.6-8mdv2007.0
- Rebuild

* Fri Sep 08 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-7mdv2007.0
- move .so symlinks to libraries that's splitted into their own packages
  to the same packages to avoid broken symlinks (fixes #22922)

* Wed Jul 19 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-6mdv2007.0
- disable glib 1.2 support (fixes #23533)
- fix no-%%clean-section
- fix non-conffile-in-etc

* Sun Jun 18 2006 Pascal Terjan <pterjan@mandriva.org> 2.0.6-5mdv2007.0
- fix build on x86_64
- add missing / in path to ldconfig (and please rpmlint by using -p if possible)

* Tue Jun 06 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 2.0.6-4mdv2007.0
- fix buildrequires
- install perl module in %%{perl_vendorarch}, not %%{perl_sitearch}
- do parallell build
- drop redundant dependencies

* Thu Jun 01 2006 Erwan Velu <velu@seanodes.com> 2.0.6-3mdk
- Fixing buildrequires

* Tue May 30 2006 Erwan Velu <velu@seanodes.com> 2.0.6-1mdk
- Initial mdv release
